@@ -15,10 +15,10 @@ using namespace Qt::Literals::StringLiterals;
 
 ImportImapSettingProgressPage::ImportImapSettingProgressPage(QWidget *parent)
     : QWidget(parent)
+    , mProgressTextEdit(new QTextEdit(this))
 {
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName("mainlayout"_L1);
-    mProgressTextEdit = new QTextEdit(this);
     mProgressTextEdit->setObjectName("textedit"_L1);
     mProgressTextEdit->setReadOnly(true);
     mainLayout->addWidget(mProgressTextEdit);
@@ -67,7 +67,7 @@ void ImportImapSettingProgressPage::start()
 
 void ImportImapSettingProgressPage::slotImportSettingsDone(const QString &name, const SieveEditorUtil::SieveServerConfig &settings)
 {
-    const QString str{i18n("Import settings from %1...", name)};
+    const QString str{i18n("Import settings from %1…", name)};
     addProgressInfo(str);
     const QString summaryStr{i18n("Import settings from %1 done", name)};
     Q_EMIT addSummaryInfo(summaryStr);
