@@ -14,14 +14,14 @@ using namespace Qt::Literals::StringLiterals;
 
 ImportImapSettingSearchPage::ImportImapSettingSearchPage(QWidget *parent)
     : QWidget(parent)
+    , mFoundProgramList(new QListWidget(this))
 {
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName("mainlayout"_L1);
-    auto label = new QLabel(i18n("Please select the program from which you like to import IMAP settings:"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Please select the program from which you like to import IMAP settings:"), this);
     label->setObjectName("label"_L1);
     mainLayout->addWidget(label);
 
-    mFoundProgramList = new QListWidget(this);
     mFoundProgramList->setObjectName("foundprogramlist"_L1);
     mainLayout->addWidget(mFoundProgramList);
     connect(mFoundProgramList, &QListWidget::itemChanged, this, &ImportImapSettingSearchPage::slotItemChanged);
