@@ -33,8 +33,7 @@ Q_SIGNALS:
     void openUrl(const QUrl &url);
 
 private:
-    Q_DISABLE_COPY(SieveEditorBookmarks)
-    KBookmarkManager *m_bookmarkManager;
+    KBookmarkManager *m_bookmarkManager = nullptr;
     KBookmarkMenu *mBookmarkMenu = nullptr;
     QMenu *const mMenu;
     SieveEditorMainWindow *const mMainWindow;
