@@ -91,11 +91,9 @@ private:
     void slotPutResult(KManageSieve::SieveJob *, bool success);
     void slotValueChanged(bool b);
     void slotCheckScriptJobFinished(const QString &errorMsg, bool success);
-
-private:
     void setModified(bool b);
     QUrl mCurrentURL;
-    KSieveUi::SieveEditorWidget *mSieveEditorWidget = nullptr;
+    KSieveUi::SieveEditorWidget *const mSieveEditorWidget;
     bool mWasActive = false;
     bool mIsNewScript = false;
 };
